==> haskell-hslua-module-version-1.1.1-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-version.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-version
version:              1.1.1
visibility:           public
id:                   hslua-module-version-1.1.1-DEg2kDNahGpHFSu8PMAdlm
key:                  hslua-module-version-1.1.1-DEg2kDNahGpHFSu8PMAdlm
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with version specifiers.
description:          Wrapper for the Data.Version.Version Haskell type.
category:             Foreign
abi:                  aa87d802114168a59b5e0f38f5f09b5a
exposed:              True
exposed-modules:      HsLua.Module.Version
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-version-1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-version-1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-version-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-version
hs-libraries:         HShslua-module-version-1.1.1-DEg2kDNahGpHFSu8PMAdlm
depends:
    base-4.17.2.1 filepath-1.4.2.2
    hslua-core-2.3.1-5aidDHfeDFxCuZfj1FStGd
    hslua-marshalling-2.3.1-Ldi8FTewZfS9dui1oYt48F
    hslua-packaging-2.3.1-D6JdqBQkSLlIfbW168mTCC text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-version/html/hslua-module-version.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-version/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-version-1.1.1-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-version.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-version
version:              1.1.1
visibility:           public
id:                   hslua-module-version-1.1.1-CmjbbrKj13AFCZlKCSkNNH
key:                  hslua-module-version-1.1.1-CmjbbrKj13AFCZlKCSkNNH
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with version specifiers.
description:          Wrapper for the Data.Version.Version Haskell type.
category:             Foreign
abi:                  4f54d60c6c8afea14e7747dc18cccde4
exposed:              True
exposed-modules:      HsLua.Module.Version
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-version-1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-version-1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-version-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-version
hs-libraries:         HShslua-module-version-1.1.1-CmjbbrKj13AFCZlKCSkNNH
depends:
    base-4.17.2.1 filepath-1.4.2.2
    hslua-core-2.3.1-6kT7iB9cHBeDlS3zVwZ7t
    hslua-marshalling-2.3.1-4XuwCenYSLcE9BL2oG3oBd
    hslua-packaging-2.3.1-IpGtVrN3A2AHAlOsQaGMF0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-version/html/hslua-module-version.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-version/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
